# <img src="https://github.com/pip-services/pip-services/raw/master/design/Logo.png" alt="Pip.Services Logo" style="max-width:30%"> <br/> IoC container for Python

This framework is a part of [Pip.Services](https://github.com/pip-services/pip-services) project.
It provides inversion-of-control component container to facilitate development of composable services and applications.

As all Pip.Services projects this framework implemented in variety of different languages: Java, .NET, Python, Node.js, Golang. 

The framework provides light-weight container that can be embedded inside service or application, or can be run by itself,
as a system process, for example. Container configuration service as recipe to instantiate and configure components inside the container.  
Default container factory provides generic functionality on demand such as logging and performance monitoring.

- **Build** - Container default factory
- **Config** - Container configuration
- **Refer** - Container references
- **Container**
- **Proccess Container**

Quick Links:

* [Downloads](https://github.com/pip-services3-python/pip-services3-container-python/blob/master/doc/Downloads.md)
* [API Reference](https://pip-services3-python.github.io/pip-services3-container-python/index.html)
* [Building and Testing](https://github.com/pip-services3-python/pip-services3-container-python/blob/master/doc/Development.md)
* [Contributing](https://github.com/pip-services3-python/pip-services3-container-python/blob/master/doc/Development.md/#contrib)

## Acknowledgements

The Python version of Pip.Services is created and maintained by **Sergey Seroukhov**